pub struct ScheduleDay {
pub date: NaiveDate,
pub lessons: Vec<Lesson>,
}Expand description
Contains information for a single day in the schedule
Fields
date: NaiveDateThe date of the day
lessons: Vec<Lesson>Lessons for the day Represented as a binary heap to always have them sorted
Implementations